clear 
clc;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% TF data For preamp #004                                
%   .----.    .----.      .---.   
%  /  ..  \  /  ..  \    / .  |   
% .  /  \  ..  /  \  .  / /|  |   
% |  |  '  ||  |  '  | / / |  |_  
% '  \  /  ''  \  /  '/  '-'    | 
%  \  `'  /  \  `'  / `----|  |-' 
%   `---''    `---''       `--'   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ID = '004';
MEASDATE = '2013/11/08';

% Values of the transimpedance resisters
zL = 100.8; % Ohm
zH = 400.9; % Ohm


fname_list={...
    './data_H1/srs011.asc', ... %01
    './data_H1/srs012.asc', ... %02
    './data_H1/srs013.asc', ... %03
    './data_H1/srs014.asc', ... %04
    './data_H1/srs015.asc', ... %05
    './data_H1/srs016.asc', ... %06
    './data_H1/srs017.asc', ... %07
    './data_H1/srs018.asc', ... %08
    './data_H1/srs019.asc', ... %09
    './data_H1/srs020.asc', ... %10
    './data_H1/srs021.asc', ... %11
    './data_H1/srs022.asc', ... %12
    './data_H1/srs023.asc', ... %13 102.4kHz ZSW=L
    './data_H1/srs024.asc', ... %14   1.6kHz ZSW=L
    './data_H1/srs025.asc', ... %15    25Hz  ZSW=L
    './data_H1/srs028.asc', ... %16 102.4kHz ZSW=H
    './data_H1/srs027.asc', ... %17   1.6kHz ZSW=H
    './data_H1/srs026.asc', ... %18    25Hz  ZSW=H
    './data_H1/srs029.asc', ... %19 102.4kHz FFT noise
    './data_H1/srs030.asc', ... %20   1.6kHz FFT noise
    './data_H1/srs031.asc', ... %21    25Hz  FFT noise
    './data_H1/srs038.asc', ... %22    25Hz  ZSW=L (again)
    './data_H1/srs039.asc', ... %23    25Hz  ZSW=L (futher again long avg)
    './data_H1/srs034.asc', ... %24 005
    './data_H1/srs033.asc', ... %25 005
    './data_H1/srs032.asc', ... %26 005
    './data_H1/srs035.asc', ... %27 005
    './data_H1/srs036.asc', ... %28 005
    './data_H1/srs037.asc' ...  %29 005
    };

%%% TF data For preamp
S1=importdata(fname_list{5},' ',17);
S2=importdata(fname_list{6},' ',17);
S3=importdata(fname_list{7},' ',17);
S4=importdata(fname_list{8},' ',17);
S5=importdata(fname_list{1},' ',14);
S6=importdata(fname_list{2},' ',14);
S7=importdata(fname_list{3},' ',14);
S8=importdata(fname_list{4},' ',14);

%%% Spe data for preamp
S13=importdata(fname_list{13},' ',14);
S14=importdata(fname_list{14},' ',14);
S15=importdata(fname_list{23},' ',14);

S16=importdata(fname_list{16},' ',14);
S17=importdata(fname_list{17},' ',14);
S18=importdata(fname_list{18},' ',14);

S19=importdata(fname_list{19},' ',14);
S20=importdata(fname_list{20},' ',14);
S21=importdata(fname_list{21},' ',14);

len=length(fname_list);

% 20mV swept sine
dat1=S1.data;
dat2=S2.data;
freqTF1 = dat1(:,1);
absTF1  = 10.^(dat1(:,2)/20);
phsTF1  = dat2(:,2);
TF1 = [freqTF1, absTF1, phsTF1];

% 10mV swept sine
dat3=S3.data;
dat4=S4.data;
freqTF2 = dat3(:,1);
absTF2  = 10.^(dat3(:,2)/20);
phsTF2  = dat4(:,2);
TF2 = [freqTF2, absTF2, phsTF2];

% 20mV random noise
dat5=S5.data;
dat6=S6.data;
freqTF3 = dat5(:,1);
absTF3  = 10.^(dat5(:,2)/20);
phsTF3  = dat6(:,2);
TF3 = [freqTF3, absTF3, phsTF3];

% 10mV random noise
dat7=S7.data;
dat8=S8.data;

freqTF4 = dat7(:,1);
absTF4  = 10.^(dat7(:,2)/20);
phsTF4  = dat8(:,2);
TF4 = [freqTF4, absTF4, phsTF4];

TFA=[TF3;TF1(2:end,:)]; % 20mV exc
TFB=[TF4;TF2(2:end,:)]; % 10mV exc
freqTFA = TFA(:,1);
absTFA  = TFA(:,2);
phsTFA  = TFA(:,3);
freqTFB = TFB(:,1);
absTFB  = TFB(:,2);
phsTFB  = TFB(:,3);

%%
SPE_L=[S15.data(3:end,:);S14.data(14:end,:);S13.data(14:end,:)];
freqSPE_L = SPE_L(:,1);
absSPE_L  = SPE_L(:,2);

SPE_H=[S18.data(3:end,:);S17.data(14:end,:);S16.data(14:end,:)];
freqSPE_H = SPE_H(:,1);
absSPE_H  = SPE_H(:,2);

SPE_N=[S21.data(3:end,:);S20.data(14:end,:);S19.data(14:end,:)];
freqSPE_N = SPE_N(:,1);
absSPE_N  = SPE_N(:,2);

%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%% Transimpedance plots
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%

%% Fig 1: Linearity check
figure(1);
clf;
orient landscape;
subplot(4,1,[1 2])
loglog(freqTFA,absTFA,'bo');
hold on;
loglog(freqTFB,absTFB,'r.');
grid on;
xlim([.1 1e5]);
ylim([.1 300]);
ylabel('Voltage Transferfunction [V/V]');
xlabel('Frequency [Hz]');
hlegend=legend(...
    '20mV excitation',...
    '10mV excitation',...
    'Location','NorthWest');
title(['\bfPreamp #' ID ' / Linearity Check (' MEASDATE ')'],'FontSize',18);

subplot(4,1,3);
semilogx(freqTFA,phsTFA,'bo');
hold on;
semilogx(freqTFB,phsTFB,'r.');
grid on;
xlim([.1 1e5]);
ylim([-180 180]);
set(gca, 'Ytick',[-180 -120 -60 0 60 120 180]);
ylabel('Phase [deg]');


subplot(4,1,4);
[ax,h1,h2]=plotyy(freqTFA,absTFB./absTFA, freqTFA,phsTFB-phsTFA,'semilogx');
grid on;
xlim([.1 1e5]);
ylim(ax(1),[.98 1.02]);
title('\bfResidual');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.98:0.01:1.02]);
xlabel('Frequency [Hz]');

ylim(ax(2),[-1 1]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-1:0.5:1]);

TFA_liso=TFA(3:end,:); % Drop first 2pts
print(['./figures/Preamp' ID '_response.pdf'],'-dpdf','-r600');
save(['./LISO/TF' ID 'A.bod'],'TFA_liso','-ascii');

%% Fig 2: Comparison with LISO circuit model (by Zach)

% Compare measured DPCD preamp TFs with LISO model
%
% ZK, 11/4/2013
%
%%%%%%

%% Load data

% == DATA ==

% Measurement frequency vector
f = freqTFA;

% DCPD 1 TF
mag1 = absTFA; % [ratio]
phi1 = phsTFA; % [phase_deg]

% == LISO ==

load('./DCPD_characterization_L1_Zach/DCPD_TF_liso.mat');
lisomag = interp1(fm,10.^(lisomag/20),f);
lisophi = interp1(fm,lisophi,f);


%% Plot

% Magnitude ratios and phase differences
magrat1 = (mag1./lisomag);
phidiff1 = (phi1-lisophi);

figure(2);
clf;
orient landscape;
subplot(4,1,[1 2])
loglog(f, mag1,'bo');
hold on;
loglog(f, lisomag,'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([.1 300]);
xlabel('Frequency [Hz]');
ylabel('Voltage Transferfunction [V/V]');
hlegend=legend(...
    'measured',...
    'liso circuit model (circuit param: nominal)',...
    'Location','SouthEast');
title(['\bfPreamp #' ID ' / Circuit model consistency check (' MEASDATE ')'],'FontSize',18);

subplot(4,1,3);
semilogx(f, phi1, 'bo');
hold on;
semilogx(f, lisophi,'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([-180 180]);
set(gca, 'Ytick',[-180 -120 -60 0 60 120 180]);
ylabel('Phase [deg]');

subplot(4,1,4);
[ax,h1,h2]=plotyy(f, magrat1, f, phidiff1,'semilogx');
grid on;
xlim([.1 1e5]);
ylim(ax(1),[.8 1.2]);
title('\bfResidual');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.8:0.1:1.2]);
xlabel('Frequency [Hz]');

ylim(ax(2),[-6 6]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-6:3:6]);

print(['./figures/Preamp' ID '_vs_liso_circuit_model.pdf'],'-dpdf','-r600');

%% Fig 3: LISO emprical model

tmp = importdata(['./LISO/TF' ID 'A.out']);
tmp_source = importdata(['./LISO/TF' ID 'A.fil'],'#');
tmp_out = importdata(['./LISO/TF' ID 'A.out'],'#');

%%
for ii=1:length(tmp_out)   
    if strfind(tmp_out{ii},'#Best')>0
        istart=ii;
    end
    if strfind(tmp_out{ii},'#Final chi')>0
        iend=ii-2;
    end
end

param_estimation = tmp_out(istart:iend);

%%

freqTF_LISO = tmp.data(:,1);
absTF_LISO = 10.^(tmp.data(:,2)/20);
phsTF_LISO = tmp.data(:,3);

absTF_LISO2   = interp1(freqTF_LISO, absTF_LISO, freqTFA);
phsTF_LISO2 = interp1(freqTF_LISO, phsTF_LISO, freqTFA);

%% Plot

% Magnitude ratios and phase differences
absTF_rat    = (absTFA./absTF_LISO2);
phsTF_diff = (phsTFA-phsTF_LISO2);

figure(3);
clf;

subplot(4,5,[4 5 9 10 14 15 19 20])
rectangle('Position', [0. 0 1 1], 'FaceColor', 'w');
%title('LISO source','FontSize',10);
text(0.01, 0.99, ...
    [
    '\bf#LISO SOURCE\rm'; ...
    tmp_source; ...
    ' ';...
    ' ';...
    ' ';...
    '\bf===========================';...
    ' ';...
    ' ';...
    ' ';...
    '\bf#Parameter Estimation\rm';...
    ' ';...
    param_estimation...
    ],...
    'VerticalAlignment','top',...
    'FontSize',6);
axis off;
hold on;


subplot(4,5,[1 2 3 6 7 8])
loglog(freqTFA, absTFA, 'bo');
hold on;
loglog(freqTF_LISO, absTF_LISO, 'r-','LineWidth',2);
grid on;
xlim([.1 1e5]);
ylim([1 300]);
ylabel('Transfer function [V/V]');
hlegend=legend(...
    'measured',...
    'LISO empirical fit',...
    'Location','SouthEast');
title(['\bfPreamp #' ID ' / LISO empirical ZPK fit (' MEASDATE ')'],'FontSize',18);
xlabel('Frequency [Hz]');

subplot(4,5,[11 12 13])
semilogx(freqTFA, phsTFA, 'bo');
hold on;
semilogx(freqTF_LISO, phsTF_LISO, 'r-','LineWidth',2);
grid on;
xlim([0.1 1e5]);
ylim([-180 180]);
set(gca, 'Ytick',[-180 -120 -60 0 60 120 180]);
ylabel('Phase [deg]');

subplot(4,5,[16 17 18])
[ax,h1,h2]=plotyy(freqTFA, absTF_rat, freqTFA, phsTF_diff,'semilogx');
grid on;
xlim(ax(1),[.1 1e5]);
ylim(ax(1),[.98 1.02]);
title('\bfResidual');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.98:0.01:1.02]);
xlabel('Frequency [Hz]');

xlim(ax(2),[.1 1e5]);
ylim(ax(2),[-1 1]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-1:0.5:1]);

orient landscape;
print(['./figures/Preamp' ID '_vs_liso_empirical_ZPKfit.pdf'],'-dpdf','-r600');

%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%% Power spectra plots
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%

figure(100);
clf;
loglog(freqSPE_H, absSPE_H, 'r');
hold on;
loglog(freqSPE_L, absSPE_L,'k');
loglog(freqSPE_N, absSPE_N,'g');
ylim([1e-9,1e-5]);
xlim([0.03, 1e5]);

% Plot DCPD preamp noise compared to LISO
%
% ZK, 11/4/2013
%
%%%%%%%%%%%%%%%%%

%% Load measured data

% Measurement frequency vector
f = freqSPE_L;

% DCPD output noise measurements [V/rtHz]
dcpd1_100 = absSPE_L; % DCPD 1, Z = 100
dcpd1_400 = absSPE_H; % DCPD 1, Z = 400

% Analyzer output noise measurement [V/rtHz]
an = absSPE_N;

%% Load model data and interpolate

load('./DCPD_characterization_L1_Zach/DCPD_noise_liso.mat');

tf100 = interp1(freqTF_LISO, absTF_LISO,f)*zL;
tf400 = interp1(freqTF_LISO, absTF_LISO,f)*zH;
nliso100 = interp1(fm, nliso100, f);
nliso400 = interp1(fm, nliso400, f);

%% Process

% Shot noise
Idc = 35e-3; % DC photocurrent (Pc = 50 mW);
Ish = sqrt(2 * 1.602e-19 * Idc) * ones(length(f),1);

% input-refer measured data
nin1_100 = abs(dcpd1_100./tf100);
nin1_400 = abs(dcpd1_400./tf400);
an100 = abs(an./tf100);
an400 = abs(an./tf400);

figure(4);
clf;
orient landscape;

loglog(f, nin1_100, 'b--');
hold on;
loglog(f, nliso100, 'r--', 'LineWidth',2);
loglog(f, an100,    'k--');
loglog(f, nin1_400, 'b');
loglog(f, nliso400, 'r',   'LineWidth',2);
loglog(f, an400,    'k');
loglog(f, Ish,      'm',   'LineWidth',2);
grid on;
ylabel('Current noise [A/rtHz]');
xlabel('Frequency [Hz]');
ylim([1e-12,1e-8]);
xlim([0.03, 1e5]);
set(gca,'XTick', 10.^[-2:5]);
title(['\bfPreamp #' ID ' / Input-referred Current noise (' MEASDATE ')'],'FontSize',18);
l = legend(...
    'DCPD (100 ohm)',...
    'LISO prediction (100 ohm)',...
    'Analyzer noise (100 ohm)', ...
    'DCPD (400 ohm)',...
    'LISO prediction (400 ohm)',...
    'Analyzer noise (400 ohm)',...
    'Shot noise (I_{DC} = 35 mA)'...
);
print(['./figures/Preamp' ID '_current_noise.pdf'],'-dpdf','-r600');


