%% Initialization 

clear

%% 006
%% Loading eLIGO data
dat006DM = load('Preamp006dmass.bod');

freq006DM = dat006DM(:,1);
abs006DM  = dat006DM(:,2)*8.0; % empirical factor for eLIGO data
phs006DM  = dat006DM(:,3);

cmp006DM  = abs006DM.*exp(1i.*phs006DM/180*pi);

%% Loading aLIGO data

d = importdata('../data_L1/mag6.TXT');
freq006ZK = d(:,1);
abs006ZK  = 10.^(d(:,2)/20);

d = importdata('../data_L1/phi6.TXT');
phs006ZK  = d(:,2);

cmp006ZK  = abs006ZK.*exp(1i.*phs006ZK/180*pi);

%% Interpolation of the aLIGO data with the eLIGO freq spacing

abs006ZKi = interp1(freq006ZK,abs006ZK,freq006DM);
phs006ZKi = interp1(freq006ZK,phs006ZK,freq006DM);

%% Plotting eLIGO/aLIGO data together

figure(1);
clf;
orient landscape;

subplot(4,1,[1 2])
loglog(freq006DM,abs006DM,'.','Color',[1 0 0]);
hold on;
loglog(freq006ZK,abs006ZK,'.','Color',[0 0 1]);
% loglog(freq006DM,abs006ZKi,'.','Color',[1 0 0]);
grid on;
ylabel('\bfMagnitude');
set(gca,'FontSize',14);
title('\bfeLIGO DCPD1 (Preamp 006) response eLIGO/aLIGO comparison');
xlim([.1 1e5]);

subplot(4,1,3)
semilogx(freq006DM, phs006DM, '.', 'Color',[1 0 0]);
hold on;
semilogx(freq006ZK, phs006ZK, '.', 'Color',[0 0 1]);
% semilogx(freq006DM, phs006ZKi,'.','Color',[1 0 0]);
grid on;
ylabel('\bfPhase [deg]');
% xlabel('\bfFrequency [Hz]');
set(gca,'FontSize',14);
set(gca,'YTick',[-180:60:180]);
xlim([.1 1e5]);

subplot(4,1,4);
[ax,h1,h2]=plotyy(freq006DM, abs006DM./abs006ZKi, freq006DM, (phs006DM-phs006ZKi),'semilogx');
grid on;

set(ax(1),'FontSize',14);
xlim(ax(1),[.1 1e5]);
ylim(ax(1),[.9 1.1]);
title('\bfDifference (eLIGO/aLIGO)');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.8:0.05:1.2]);
xlabel('\bfFrequency [Hz]');

set(ax(2),'FontSize',14);
xlim(ax(2),[.1 1e5]);
ylim(ax(2),[-6 6]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-6:3:6]);

print(['./figures/Preamp006_aLIGO_eLIGO_comparison.pdf'],'-dpdf','-r600');

%% 008
%% Loading eLIGO data
dat008DM = load('Preamp008dmass.bod');

freq008DM = dat008DM(:,1);
abs008DM  = dat008DM(:,2)*6.95; % empirical factor for eLIGO data
phs008DM  = dat008DM(:,3);

cmp008DM  = abs008DM.*exp(1i.*phs008DM/180*pi);

%% Loading aLIGO data

d = importdata('../data_L1/mag8.TXT');
freq008ZK = d(:,1);
abs008ZK  = 10.^(d(:,2)/20);

d = importdata('../data_L1/phi8.TXT');
phs008ZK  = d(:,2);

cmp008ZK  = abs008ZK.*exp(1i.*phs008ZK/180*pi);

%% Interpolation of the aLIGO data with the eLIGO freq spacing

abs008ZKi = interp1(freq008ZK,abs008ZK,freq008DM);
phs008ZKi = interp1(freq008ZK,phs008ZK,freq008DM);

%% Plotting eLIGO/aLIGO data together

figure(2);
clf;
orient landscape;

subplot(4,1,[1 2])
loglog(freq008DM,abs008DM,'.','Color',[1 0 0]);
hold on;
loglog(freq008ZK,abs008ZK,'.','Color',[0 0 1]);
% loglog(freq008DM,abs008ZKi,'.','Color',[1 0 0]);
grid on;
ylabel('\bfMagnitude');
set(gca,'FontSize',14);
title('\bfeLIGO DCPD2 (Preamp 008) response eLIGO/aLIGO comparison');
xlim([.1 1e5]);

subplot(4,1,3)
semilogx(freq008DM, phs008DM, '.', 'Color',[1 0 0]);
hold on;
semilogx(freq008ZK, phs008ZK, '.', 'Color',[0 0 1]);
% semilogx(freq008DM, phs008ZKi,'.','Color',[1 0 0]);
grid on;
ylabel('\bfPhase [deg]');
% xlabel('\bfFrequency [Hz]');
set(gca,'FontSize',14);
set(gca,'YTick',[-180:60:180]);
xlim([.1 1e5]);

subplot(4,1,4);
[ax,h1,h2]=plotyy(freq008DM, abs008DM./abs008ZKi, freq008DM, (phs008DM-phs008ZKi),'semilogx');
grid on;

set(ax(1),'FontSize',14);
xlim(ax(1),[.1 1e5]);
ylim(ax(1),[.9 1.1]);
title('\bfDifference (eLIGO/aLIGO)');
ylabel(ax(1),'Ratio');
set(ax(1), 'Ytick',[0.8:0.05:1.2]);
xlabel('\bfFrequency [Hz]');

set(ax(2),'FontSize',14);
xlim(ax(2),[.1 1e5]);
ylim(ax(2),[-6 6]);
ylabel(ax(2),'Phase Diff [deg]');
set(ax(2), 'Ytick',[-6:3:6]);

print(['./figures/Preamp008_aLIGO_eLIGO_comparison.pdf'],'-dpdf','-r600');

%% Data Stitching 
% 006 

f_stitch = 30;
iDM_stitch = sum(freq006DM<30)+1;
iZK_stitch = sum(freq006ZK<30);

freq006 = [freq006ZK(1:iZK_stitch); freq006DM(iDM_stitch:end)];
cmp006 =  [cmp006ZK(1:iZK_stitch);  cmp006DM(iDM_stitch:end)];

[abs006, phs006] = cmp2absphs(cmp006);
dat006 = [freq006 abs006 phs006];

save('Preamp006.bod', 'dat006', '-ascii');

% 008

f_stitch = 30;
iDM_stitch = sum(freq008DM<30)+1;
iZK_stitch = sum(freq008ZK<30);

freq008 = [freq008ZK(1:iZK_stitch); freq008DM(iDM_stitch:end)];
cmp008 =  [cmp008ZK(1:iZK_stitch);  cmp008DM(iDM_stitch:end)];

[abs008, phs008] = cmp2absphs(cmp008);
dat008 = [freq008 abs008 phs008];

save('Preamp008.bod', 'dat008', '-ascii');
